==> configurablefunctions-0.0.4-sources.jar: org/ct42/fnflow/cfgfns/ConfigurableFunctionConfiguration.java <==
/*
 * Copyright 2025-2025 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ct42.fnflow.cfgfns;

import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.core.env.Environment;

/**
 * Configuration for Bean registry and AOT processor.
 *
 * @author Claas Thiele
 */
@AutoConfiguration
public class ConfigurableFunctionConfiguration {
    /**
     * Property prefix for configurable functions configurations.
     */
    public static final String FUNCTIONS_PREFIX = "cfgfns";


    @Bean
    public static ConfigurableFunctionRegistrar configurableFunctionRegistrar(Environment environment) {
        return new ConfigurableFunctionRegistrar(environment);
    }

    @Bean
    public static FnPropsInjectingPostProcessor fnPropsInjectingPostProcessor(ApplicationContext applicationContext) {
        return new FnPropsInjectingPostProcessor(applicationContext);
    }

    @Bean
    static ListenerBeanFactoryInitializationAotProcessor listenerBeanFactoryInitializationAotProcessor() {
        return new ListenerBeanFactoryInitializationAotProcessor();
    }
}

==> configurablefunctions-0.0.6-sources.jar: org/ct42/fnflow/cfgfns/ConfigurableFunctionConfiguration.java <==
/*
 * Copyright 2025-2025 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ct42.fnflow.cfgfns;

import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.context.ApplicationContext;
import org.springframework.context.annotation.Bean;
import org.springframework.core.env.Environment;
import org.springframework.validation.Validator;

/**
 * Configuration for Bean registry and AOT processor.
 *
 * @author Claas Thiele
 * @author Sajjad Safaeian
 */
@AutoConfiguration
public class ConfigurableFunctionConfiguration {
    /**
     * Property prefix for configurable functions configurations.
     */
    public static final String FUNCTIONS_PREFIX = "cfgfns";


    @Bean
    public static ConfigurableFunctionRegistrar configurableFunctionRegistrar(Environment environment) {
        return new ConfigurableFunctionRegistrar(environment);
    }

    @Bean
    public static FnPropsInjectingPostProcessor fnPropsInjectingPostProcessor(ApplicationContext applicationContext, Validator validator) {
        return new FnPropsInjectingPostProcessor(applicationContext, validator);
    }

    @Bean
    static ListenerBeanFactoryInitializationAotProcessor listenerBeanFactoryInitializationAotProcessor() {
        return new ListenerBeanFactoryInitializationAotProcessor();
    }
}
